from stomp.const import EOL
from stomp.const import EOF


class RawFrame(object):
    """Represents a raw frame instance parsed from a
    data stream received from the STOMP server.
    """
    __slots__ = ['_frame_type', '_raw_headers', '_message_body']

    message_body= property(lambda self: self._message_body)
    frame_type  = property(lambda self: self._frame_type)
    raw_headers = property(lambda self: self._raw_headers)

    @classmethod
    def fromtuple(cls, args):
        return cls(*args)

    def __init__(self, frame_type, raw_headers, body):
        self._frame_type = frame_type
        self._raw_headers = raw_headers
        self._message_body = body

    def __hash__(self):
        # The headers of a frame SHOULD uniquely identify
        # the frame.
        return hash(self._raw_headers)

    def __eq__(self):
        return isinstance(self, type(other))\
            and (hash(self) == hash(other))

    def _iter__(self):
        return iter([self._frame_type, self._raw_headers,
            self._message_body])

    def __str__(self):
        return self._frame_type\
            + EOL + self._raw_headers\
            + (EOL*2) + self._message_body\
            + EOF
