import queue
import time
import threading

from stomp.datastructures import Frame


class FrameDispatcher(object):
    """Dispatches incoming frames to the registered consumers
    and listeners.
    """

    def __init__(self):
        self._queue = queue.Queue()

    def dispatch(self, frame):
        """Dispatches `frame` to consumers or listeners.

        If `frame` was published to a Queue, select a random
        consumer; if `frame` was published to a Topic, dispatch
        to all listeners.
        """
        self._queue.put(frame)

    def __call__(self, raw_frame):
        self.dispatch(Frame.fromraw(raw_frame))
