from stomp.frame.frame import Frame
from stomp import defaults
from stomp import const
from stomp import headers


class Connect(Frame):
    """Represents a ``CONNECT`` frame."""
    default_version = defaults.DEFAULT_VERSION

    def __init__(self, vhost, login, passcode, server_heartbeats=0, 
        client_heartbeats=0, version=None):
        """Initialize a new :class:`Connect` instance.

        Args:
            vhost (str): identifies the virtual host to connect
                with.
            login (str): username to authenticate as.
            passcode (str): password to authenticate with.
            server_heartbeats (int): specifies the interval of the
                heartbeats we want to receive, in milliseconds.
            client_heartbeats (int): specifies the interval of the
                heartbeats we are sending, in milliseconds.
            version (str): specifies the STOMP protocol version;
                defaults to 1.2
        """
        frame_headers = {
            headers.HOST: vhost,
            headers.ACCEPT_VERSION: version or self.default_version,
            headers.LOGIN: login,
            headers.PASSCODE: passcode,
            headers.HEARTBEAT: '{0},{1}'.format(client_heartbeats, 
                server_heartbeats)
        }
        Frame.__init__(self, const.CONNECT, headers=frame_headers)
