from stomp.const import EOL
from stomp.frame.header import FrameHeader


class FrameHeaders(object):
    """Represents a set of headers on a STOMP frame."""
    types = {
        'content-length': int
    }

    @classmethod
    def parse(cls, raw_data):
        """Parses headers from raw data received from the STOMP
        server.
        """
        return cls([FrameHeader.parse(x) for x in raw_data.split(EOL)])

    def __init__(self, headers):
        self._headers = {x.name: x for x in headers}

    def _get(self, name):
        return self.types[name](self._headers[name].value)

    def __getitem__(self, key):
        return self._get(key)

    def __contains__(self, key):
        return key in self._headers